@@ -29,7 +29,6 @@ from zunclient.i18n import _
 
 
 def _container_columns(container):
-    del container._info['links']
     return container._info.keys()
 
 
@@ -119,7 +118,7 @@ class CreateContainer(command.ShowOne):
             help='Send command to the container')
         parser.add_argument(
             '--hint',
-            metavar='key=value',
+            metavar='<key=value>',
             action='append',
             default=[],
             help='The key-value pair(s) for scheduler to select host. '
@@ -127,7 +126,7 @@ class CreateContainer(command.ShowOne):
                  'May be used multiple times.')
         parser.add_argument(
             '--net',
-            metavar='<auto, networks=networks, port=port-uuid,'
+            metavar='<auto, network=network, port=port-uuid,'
                     'v4-fixed-ip=ip-addr,v6-fixed-ip=ip-addr>',
             action='append',
             default=[],
@@ -138,6 +137,23 @@ class CreateContainer(command.ShowOne):
                  ' port: attach container to the neutron port with this UUID. '
                  'v4-fixed-ip: IPv4 fixed address for container. '
                  'v6-fixed-ip: IPv6 fixed address for container.')
+        parser.add_argument(
+            '--rm',
+            dest='auto_remove',
+            action='store_true',
+            default=False,
+            help='Automatically remove the container when it exits')
+        parser.add_argument(
+            '--runtime',
+            choices=['runc'],
+            metavar='<runtime>',
+            help='The container runtime tool to create container with. '
+                 'It can have following value: "runc"')
+        parser.add_argument(
+            '--hostname',
+            metavar='<hostname>',
+            help='Container host name'
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -152,6 +168,7 @@ class CreateContainer(command.ShowOne):
         opts['labels'] = zun_utils.format_args(parsed_args.label)
         opts['image_pull_policy'] = parsed_args.image_pull_policy
         opts['image_driver'] = parsed_args.image_driver
+        opts['auto_remove'] = parsed_args.auto_remove
         if parsed_args.security_group:
             opts['security_groups'] = parsed_args.security_group
         if parsed_args.command:
@@ -163,6 +180,8 @@ class CreateContainer(command.ShowOne):
             opts['interactive'] = True
         opts['hints'] = zun_utils.format_args(parsed_args.hint)
         opts['nets'] = zun_utils.parse_nets(parsed_args.net)
+        opts['runtime'] = parsed_args.runtime
+        opts['hostname'] = parsed_args.hostname
 
         opts = zun_utils.remove_null_parms(**opts)
         container = client.containers.create(**opts)
@@ -642,7 +661,7 @@ class RunContainer(command.ShowOne):
             help='Send command to the container')
         parser.add_argument(
             '--hint',
-            metavar='key=value',
+            metavar='<key=value>',
             action='append',
             default=[],
             help='The key-value pair(s) for scheduler to select host. '
@@ -650,7 +669,7 @@ class RunContainer(command.ShowOne):
                  'May be used multiple times.')
         parser.add_argument(
             '--net',
-            metavar='<auto, networks=networks, port=port-uuid,'
+            metavar='<auto, network=network, port=port-uuid,'
                     'v4-fixed-ip=ip-addr,v6-fixed-ip=ip-addr>',
             action='append',
             default=[],
@@ -661,6 +680,23 @@ class RunContainer(command.ShowOne):
                  ' port: attach container to the neutron port with this UUID. '
                  'v4-fixed-ip: IPv4 fixed address for container. '
                  'v6-fixed-ip: IPv6 fixed address for container.')
+        parser.add_argument(
+            '--rm',
+            dest='auto_remove',
+            action='store_true',
+            default=False,
+            help='Automatically remove the container when it exits')
+        parser.add_argument(
+            '--runtime',
+            metavar='<runtime>',
+            choices=['runc'],
+            help='The container runtime tool to create container with. '
+                 'It can have following value: "runc"')
+        parser.add_argument(
+            '--hostname',
+            metavar='<hostname>',
+            help='Container host name'
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -675,6 +711,7 @@ class RunContainer(command.ShowOne):
         opts['labels'] = zun_utils.format_args(parsed_args.label)
         opts['image_pull_policy'] = parsed_args.image_pull_policy
         opts['image_driver'] = parsed_args.image_driver
+        opts['auto_remove'] = parsed_args.auto_remove
         if parsed_args.security_group:
             opts['security_groups'] = parsed_args.security_group
         if parsed_args.command:
@@ -686,6 +723,8 @@ class RunContainer(command.ShowOne):
             opts['interactive'] = True
         opts['hints'] = zun_utils.format_args(parsed_args.hint)
         opts['nets'] = zun_utils.parse_nets(parsed_args.net)
+        opts['runtime'] = parsed_args.runtime
+        opts['hostname'] = parsed_args.hostname
 
         opts = zun_utils.remove_null_parms(**opts)
         container = client.containers.run(**opts)
@@ -771,7 +810,7 @@ class TopContainer(command.Command):
                 print("%-20s") % info,
 
 
-class UpdateContainer(command.Command):
+class UpdateContainer(command.ShowOne):
     """Update one or more attributes of the container"""
     log = logging.getLogger(__name__ + ".UpdateContainer")
 
@@ -800,13 +839,9 @@ class UpdateContainer(command.Command):
         opts = zun_utils.remove_null_parms(**opts)
         if not opts:
             raise exc.CommandError("You must update at least one property")
-        try:
-            client.containers.update(container, **opts)
-            print(_('Request to update container %s has been accepted')
-                  % container)
-        except Exception as e:
-            print("update for container %(container)s failed: %(e)s" %
-                  {'container': container, 'e': e})
+        container = client.containers.update(container, **opts)
+        columns = _container_columns(container)
+        return columns, utils.get_item_properties(container, columns)
 
 
 class AttachContainer(command.Command):
@@ -913,22 +948,15 @@ class CommitContainer(command.Command):
             metavar='<container>',
             help='ID or name of the (container)s to commit.')
         parser.add_argument(
-            '--repository',
-            required=True,
-            metavar='<repository>',
-            help='Repository of the new image.')
-        parser.add_argument(
-            '--tag',
-            metavar='<tag>',
-            help='Tag of the new iamge')
+            'repository',
+            metavar='<repository>[:<tag>]',
+            help='Repository and tag of the new image.')
         return parser
 
     def take_action(self, parsed_args):
         client = _get_client(self, parsed_args)
         container = parsed_args.container
-        opts = {}
-        opts['repository'] = parsed_args.repository
-        opts['tag'] = parsed_args.tag
+        opts = zun_utils.check_commit_container_args(parsed_args)
         opts = zun_utils.remove_null_parms(**opts)
         try:
             image = client.containers.commit(container, **opts)
@@ -937,3 +965,96 @@ class CommitContainer(command.Command):
         except Exception as e:
             print("commit container %(container)s failed: %(e)s" %
                   {'container': container, 'e': e})
+
+
+class AddSecurityGroup(command.Command):
+    """Add security group for specified container."""
+    log = logging.getLogger(__name__ + ".AddSecurityGroup")
+
+    def get_parser(self, prog_name):
+        parser = super(AddSecurityGroup, self).get_parser(prog_name)
+        parser.add_argument(
+            'container',
+            metavar='<container>',
+            help='ID or name of the container to add security group.')
+        parser.add_argument(
+            'security_group',
+            metavar='<security_group>',
+            help='The security group for specified container. ')
+        return parser
+
+    def take_action(self, parsed_args):
+        client = _get_client(self, parsed_args)
+        opts = {}
+        opts['id'] = parsed_args.container
+        opts['security_group'] = parsed_args.security_group
+        opts = zun_utils.remove_null_parms(**opts)
+        try:
+            client.containers.add_security_group(**opts)
+            print("Request to add security group for container %s "
+                  "has been accepted." % parsed_args.container)
+        except Exception as e:
+            print("Add security group for container %(container)s failed: "
+                  "%(e)s" % {'container': parsed_args.container, 'e': e})
+
+
+class NetworkDetach(command.Command):
+    """Detach neutron network from specified container."""
+    log = logging.getLogger(__name__ + ".NetworkDetach")
+
+    def get_parser(self, prog_name):
+        parser = super(NetworkDetach, self).get_parser(prog_name)
+        parser.add_argument(
+            'container',
+            metavar='<container>',
+            help='ID or name of the container to detach network.')
+        parser.add_argument(
+            'network',
+            metavar='<network>',
+            help='The network for specified container to detach.')
+        return parser
+
+    def take_action(self, parsed_args):
+        client = _get_client(self, parsed_args)
+        opts = {}
+        opts['container'] = parsed_args.container
+        opts['network'] = parsed_args.network
+        opts = zun_utils.remove_null_parms(**opts)
+        try:
+            client.containers.network_detach(**opts)
+            print("Request to detach network for container %s "
+                  "has been accepted." % parsed_args.container)
+        except Exception as e:
+            print("Detach network for container %(container)s failed: "
+                  "%(e)s" % {'container': parsed_args.container, 'e': e})
+
+
+class NetworkAttach(command.Command):
+    """Attach neutron network to specified container."""
+    log = logging.getLogger(__name__ + ".NetworkAttach")
+
+    def get_parser(self, prog_name):
+        parser = super(NetworkAttach, self).get_parser(prog_name)
+        parser.add_argument(
+            'container',
+            metavar='<container>',
+            help='ID or name of the container to attach network.')
+        parser.add_argument(
+            'network',
+            metavar='<network>',
+            help='The network for specified container to attach.')
+        return parser
+
+    def take_action(self, parsed_args):
+        client = _get_client(self, parsed_args)
+        opts = {}
+        opts['container'] = parsed_args.container
+        opts['network'] = parsed_args.network
+        opts = zun_utils.remove_null_parms(**opts)
+        try:
+            client.containers.network_attach(**opts)
+            print("Request to attach network to container %s "
+                  "has been accepted." % parsed_args.container)
+        except Exception as e:
+            print("Attach network to container %(container)s failed: "
+                  "%(e)s" % {'container': parsed_args.container, 'e': e})
