@@ -32,6 +32,9 @@ CONTAINER1 = {'id': '1234',
               'hints': {'hint1': 'bar'},
               'restart_policy': 'no',
               'security_groups': ['test'],
+              'auto_remove': True,
+              'runtime': 'runc',
+              'hostname': 'testhost',
               }
 
 CONTAINER2 = {'id': '1235',
@@ -48,6 +51,9 @@ CONTAINER2 = {'id': '1235',
               'hints': {'hint2': 'bar'},
               'restart_policy': 'on-failure:5',
               'security_groups': ['test'],
+              'auto_remove': False,
+              'runtime': 'runc',
+              'hostname': 'testhost'
               }
 
 CREATE_CONTAINER1 = copy.deepcopy(CONTAINER1)
@@ -66,6 +72,7 @@ path = "/tmp/test.txt"
 data = "/tmp/test.tar"
 repo = "repo-test"
 tag = "tag-test"
+security_group = "testsg"
 
 fake_responses = {
     '/v1/containers':
@@ -296,6 +303,30 @@ fake_responses = {
             None,
         ),
     },
+    '/v1/containers/%s/add_security_group?%s'
+    % (CONTAINER1['id'], parse.urlencode({'name': security_group})):
+    {
+        'POST': (
+            {},
+            None,
+        ),
+    },
+    '/v1/containers/%s/network_detach?%s'
+    % (CONTAINER1['id'], parse.urlencode({'network': 'neutron_network'})):
+    {
+        'POST': (
+            {},
+            None,
+        ),
+    },
+    '/v1/containers/%s/network_attach?%s'
+    % (CONTAINER1['id'], parse.urlencode({'network': 'neutron_network'})):
+    {
+        'POST': (
+            {},
+            None,
+        ),
+    },
 }
 
 
@@ -612,3 +643,39 @@ class ContainerManagerTest(testtools.TestCase):
         ]
         self.assertEqual(expect, self.api.calls)
         self.assertIsNone(containers)
+
+    def test_containers_add_security_group(self):
+        containers = self.mgr.add_security_group(
+            CONTAINER1['id'], security_group)
+        expect = [
+            ('POST', '/v1/containers/%s/add_security_group?%s'
+             % (CONTAINER1['id'],
+                parse.urlencode({'name': security_group})),
+                {'Content-Length': '0'}, None)
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertTrue(containers)
+
+    def test_containers_network_detach(self):
+        containers = self.mgr.network_detach(
+            CONTAINER1['id'], 'neutron_network')
+        expect = [
+            ('POST', '/v1/containers/%s/network_detach?%s'
+             % (CONTAINER1['id'],
+                parse.urlencode({'network': 'neutron_network'})),
+                {'Content-Length': '0'}, None)
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertTrue(containers)
+
+    def test_containers_network_attach(self):
+        containers = self.mgr.network_attach(
+            CONTAINER1['id'], 'neutron_network')
+        expect = [
+            ('POST', '/v1/containers/%s/network_attach?%s'
+             % (CONTAINER1['id'],
+                parse.urlencode({'network': 'neutron_network'})),
+                {'Content-Length': '0'}, None)
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertTrue(containers)
