@@ -49,6 +49,9 @@ def _show_container(container):
 @utils.arg('--workdir',
            metavar='<workdir>',
            help='The working directory for commands to run in')
+@utils.arg('--rm',
+           action='store_true',
+           help='Automatically remove the container when it exits')
 @utils.arg('--label',
            metavar='<KEY=VALUE>',
            action='append', default=[],
@@ -82,7 +85,7 @@ def _show_container(container):
                 '"docker": pull the image from Docker Hub. '
                 '"glance": pull the image from Glance. ')
 @utils.arg('--security-group',
-           metavar='security-group',
+           metavar='<security-group>',
            action='append', default=[],
            help='The name of security group for the container. '
                 'May be used multiple times.')
@@ -109,6 +112,15 @@ def _show_container(container):
                 'port: attach container to the neutron port with this UUID. '
                 'v4-fixed-ip: IPv4 fixed address for container. '
                 'v6-fixed-ip: IPv6 fixed address for container.')
+@utils.arg('--runtime',
+           metavar='<runtime>',
+           choices=['runc'],
+           help='The container runtime tool to create container with. '
+                'It can have following value: "runc"')
+@utils.arg('--hostname',
+           metavar='<hostname>',
+           default=None,
+           help='Container host name')
 def do_create(cs, args):
     """Create a container."""
     opts = {}
@@ -117,12 +129,15 @@ def do_create(cs, args):
     opts['memory'] = args.memory
     opts['cpu'] = args.cpu
     opts['environment'] = zun_utils.format_args(args.environment)
+    opts['auto_remove'] = args.rm
     opts['workdir'] = args.workdir
     opts['labels'] = zun_utils.format_args(args.label)
     opts['image_pull_policy'] = args.image_pull_policy
     opts['image_driver'] = args.image_driver
     opts['hints'] = zun_utils.format_args(args.hint)
     opts['nets'] = zun_utils.parse_nets(args.net)
+    opts['runtime'] = args.runtime
+    opts['hostname'] = args.hostname
 
     if args.security_group:
         opts['security_groups'] = args.security_group
@@ -425,6 +440,9 @@ def do_kill(cs, args):
 @utils.arg('--workdir',
            metavar='<workdir>',
            help='The working directory for commands to run in')
+@utils.arg('--rm',
+           action='store_true',
+           help='Automatically remove the container when it exits')
 @utils.arg('--label',
            metavar='<KEY=VALUE>',
            action='append', default=[],
@@ -458,7 +476,7 @@ def do_kill(cs, args):
                 '"docker": pull the image from Docker Hub. '
                 '"glance": pull the image from Glance. ')
 @utils.arg('--security-group',
-           metavar='security-group',
+           metavar='<security-group>',
            action='append', default=[],
            help='The name of security group for the container. '
                 'May be used multiple times.')
@@ -485,6 +503,15 @@ def do_kill(cs, args):
                 'port: attach container to the neutron port with this UUID. '
                 'v4-fixed-ip: IPv4 fixed address for container. '
                 'v6-fixed-ip: IPv6 fixed address for container.')
+@utils.arg('--runtime',
+           metavar='<runtime>',
+           choices=['runc'],
+           help='The container runtime tool to create container with. '
+                'It can have following value: "runc"')
+@utils.arg('--hostname',
+           metavar='<hostname>',
+           default=None,
+           help='Container hostname')
 def do_run(cs, args):
     """Run a command in a new container."""
     opts = {}
@@ -494,11 +521,14 @@ def do_run(cs, args):
     opts['cpu'] = args.cpu
     opts['environment'] = zun_utils.format_args(args.environment)
     opts['workdir'] = args.workdir
+    opts['auto_remove'] = args.rm
     opts['labels'] = zun_utils.format_args(args.label)
     opts['image_pull_policy'] = args.image_pull_policy
     opts['image_driver'] = args.image_driver
     opts['hints'] = zun_utils.format_args(args.hint)
     opts['nets'] = zun_utils.parse_nets(args.net)
+    opts['runtime'] = args.runtime
+    opts['hostname'] = args.hostname
 
     if args.security_group:
         opts['security_groups'] = args.security_group
@@ -646,20 +676,13 @@ def do_stats(cs, args):
 @utils.arg('container',
            metavar='<container>',
            help='ID or name of the container to commit.')
-@utils.arg('--repository',
-           metavar='<repository>',
-           required=True,
-           help='The repository of the image.')
-@utils.arg('--tag',
-           metavar='<tag>',
-           help='The tag of the image')
+@utils.arg('repository',
+           metavar='<repository>[:<tag>]',
+           help='The repository and tag of the image.')
 def do_commit(cs, args):
     """Create a new image from a container's changes."""
-    opts = {}
-    if args.repository is not None:
-        opts['repository'] = args.repository
-    if args.tag is not None:
-        opts['tag'] = args.tag
+    opts = zun_utils.check_commit_container_args(args)
+    opts = zun_utils.remove_null_parms(**opts)
     try:
         image = cs.containers.commit(args.container, **opts)
         print("Request to commit container %s has been accepted. "
@@ -667,3 +690,66 @@ def do_commit(cs, args):
     except Exception as e:
         print("Commit for container %(container)s failed: %(e)s" %
               {'container': args.container, 'e': e})
+
+
+@utils.arg('container',
+           metavar='<container>',
+           help='ID or name of the container to add security group.')
+@utils.arg('security_group',
+           metavar='<security_group>',
+           help='The security group for specified container.')
+def do_add_security_group(cs, args):
+    """Add security group for specified container."""
+    opts = {}
+    opts['id'] = args.container
+    opts['security_group'] = args.security_group
+    opts = zun_utils.remove_null_parms(**opts)
+    try:
+        cs.containers.add_security_group(**opts)
+        print("Request to add security group for container %s "
+              "has been accepted." % args.container)
+    except Exception as e:
+        print("Add security group for container %(container)s "
+              "failed: %(e)s" % {'container': args.container, 'e': e})
+
+
+@utils.arg('container',
+           metavar='<container>',
+           help='ID or name of the container to detach the network.')
+@utils.arg('network',
+           metavar='<network>',
+           help='The neutron network that container will detach from.')
+def do_network_detach(cs, args):
+    """Detach a network from the container."""
+    opts = {}
+    opts['container'] = args.container
+    opts['network'] = args.network
+    opts = zun_utils.remove_null_parms(**opts)
+    try:
+        cs.containers.network_detach(**opts)
+        print("Request to detach network from container %s "
+              "has been accepted." % args.container)
+    except Exception as e:
+        print("Detach network from container %(container)s "
+              "failed: %(e)s" % {'container': args.container, 'e': e})
+
+
+@utils.arg('container',
+           metavar='<container>',
+           help='ID or name of the container to attach network.')
+@utils.arg('network',
+           metavar='<network>',
+           help='The neutron network that container will attach to.')
+def do_network_attach(cs, args):
+    """Attach a network to the container."""
+    opts = {}
+    opts['container'] = args.container
+    opts['network'] = args.network
+    opts = zun_utils.remove_null_parms(**opts)
+    try:
+        cs.containers.network_attach(**opts)
+        print("Request to attach network to container %s "
+              "has been accepted." % args.container)
+    except Exception as e:
+        print("Attach network to container %(container)s "
+              "failed: %(e)s" % {'container': args.container, 'e': e})
